AGW Logo

svn SVN Revision 68881 For multidirdialog

This file contains the SVN revision history for multidirdialog, at revision 68881.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 17-Oct-2008 19:15:31 UTC
  • Committer: AG
  • File Size: 24955 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

  • AGW: General overhaul of the documentation, much improved. All the widgets have their own sample usage in the docs as well;

  • FlatNotebook: Added the FNB_NAV_BUTTONS_WHEN_NEEDED style, which hides the navigation left/right arrows if all tabs fit;

  • RibbonBar: - Added the EVT_RIBBONBAR_TAB_LEFT_DCLICK event, which generates a special event

    when a ribbon bar tab is double-clicked;

    • Added support for toggle buttons;
    • Improved support for ribbon panel sizers: panels with sizers should now automatically minimise at small sizes, and behave properly when popping up from a minimised state;
    • Added tooltips via SetToolTip for those buttons which have the help_string attribute set.
  • XLSGrid: a new widget was added to AGW, termed XLSGrid. It’s based on wx.grid.Grid and can be used to faithfully reproduce the appearance of a Microsoft Excel spreadsheets.


svn_diff Diff To Previous Version (68362)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/multidirdialog.py     2011/07/24 21:36:47     68362
+++ wxPython/3rdParty/AGW/agw/multidirdialog.py     2011/08/25 16:40:17     68881
@@ -2,7 +2,7 @@
# MULTIDIRDIALOG wxPython IMPLEMENTATION
#
# Andrea Gavana, @ 07 October 2008
# Latest Revision: 12 Sep 2010, 10.00 GMT
#
#
# TODO List
@@ -36,7 +36,7 @@
This class represents a possible replacement for `wx.DirDialog`, with the additional
ability of selecting multiple folders at once. It may be useful when you wish to
present to the user a directory browser which allows multiple folder selections.
-MultiDirDialog sports the following features:
+L{MultiDirDialog} sports the following features:

* Ability to select a single or mutliple folders, depending on the style passed;
* More colourful and eye-catching buttons;
@@ -45,10 +45,41 @@
And a lot more. Check the demo for an almost complete review of the functionalities.


+Usage
+=====
+
+Usage example::
+
+    import os
+    import wx
+
+    import wx.lib.agw.multidirdialog as MDD
+
+    # Our normal wxApp-derived class, as usual
+    app = wx.App(0)
+
+    dlg = MDD.MultiDirDialog(None, title="Custom MultiDirDialog", defaultPath=os.getcwd(),
+                             agwStyle=MDD.DD_MULTIPLE|MDD.DD_DIR_MUST_EXIST)
+
+    if dlg.ShowModal() != wx.ID_OK:
+        print "You Cancelled The Dialog!"
+        dlg.Destroy()
+        return
+
+    paths = dlg.GetPaths()
+    for indx, path in enumerate(paths):
+        print "Path %d: %s"%(indx+1, path)
+
+    dlg.Destroy()
+
+    app.MainLoop()
+
+
+
Supported Platforms
===================

-MultiDirDialog has been tested on the following platforms:
+L{MultiDirDialog} has been tested on the following platforms:
* Windows (Windows XP).


@@ -75,9 +106,9 @@
License And Version
===================

-MultiDirDialog is distributed under the wxPython license.
+L{MultiDirDialog} is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 12 Sep 2010, 10.00 GMT
+Latest Revision: Andrea Gavana @ 17 Aug 2011, 15.00 GMT

Version 0.3
Tree
@@ -2,7 +2,7 @@
#
# Andrea Gavana, @ 07 October 2008
-# Latest Revision: 12 Sep 2010, 10.00 GMT
+# Latest Revision: 17 Aug 2011, 15.00 GMT
#
#

Table Of Contents

Previous topic

SVN Revision 68362 For multidirdialog

Next topic

peakmeter